#!/usr/local/bin/perl
use strict;
use warnings;

use FindBin;
use File::Spec;
use lib File::Spec->catdir($FindBin::Bin, 'lib');

use Encode;
use Term::Encoding qw/term_encoding/;
use Pod::Usage;
use DateTime;

use URI::Fetch::HTML;
use App::Schema;

my $user_name = 'naoya';

my %commands = (
    list => \&list_events,
    add  => \&add_events,
    del  => \&del_events,
);

my $schema = App::Schema->connect;
my $user  = $schema->resultset('User')->find({ name => $user_name})
    or die "No such user ($user_name)";

my $command = $commands{shift || 'list'} or pod2usage(2);
$command->($user, @ARGV);

sub list_events {
    my $user = shift;
    my $rs = $user->bookmarks;
    while (my $bookmark = $rs->next) {
        print encode(term_encoding, $bookmark->entry->as_string);
        print encode(term_encoding, $bookmark->comment) if $bookmark->comment;
        printf " (%s)\n\n", $bookmark->created_on->ymd('/');
    }
}

sub add_events {
    my ($user, $url, $comment) = @_;
    return unless $url;

    my $entry = $schema->resultset('Entry')->find_or_new({ url => $url });
    $entry->title(URI::Fetch::HTML->fetch($url)->title);
    $entry->created_on(DateTime->now);
    $entry->insert;

    if (not $user->already_has($entry)) {
        $user->add_bookmark($entry, decode(term_encoding, $comment));
        printf encode(term_encoding, $entry->as_string),
    }
}

sub del_events {
    my ($user, $entry_id) = @_;
    $user->delete_bookmark($entry_id)
        or die "Couldn't delete bookmark with $entry_id";
}

__END__

=head1 NAME

bookmark.pl - a CLI for bookmark app

=head1 SYNOPSIS

  bookmark.pl list
    List all entries in your bookmark.

  bookmark.pl add <url> [comment]
    Add a new entry to your bookmark.

  bookmark.pl del <entry_id>
    Delete an entry with entry_id.

=cut
