package App::Schema::Entry;
use strict;
use warnings;
use base qw/DBIx::Class/;
use URI;

__PACKAGE__->load_components(qw/UTF8Columns InflateColumn::DateTime PK::Auto Core/);
__PACKAGE__->table('entry');
__PACKAGE__->add_columns(qw/id url title/);
__PACKAGE__->add_column(created_on => {
    data_type => 'datetime'
});
__PACKAGE__->set_primary_key('id');
__PACKAGE__->utf8_columns(qw/title/);
__PACKAGE__->inflate_column(
    'url',
    { inflate => sub { URI->new(shift) } },
    { deflate => sub { my $uri = shift; ref $uri ? $uri->as_string : $uri } }
);

__PACKAGE__->has_many(
    bookmarks => 'App::Schema::Bookmark', {
        'foreign.entry_id' => 'self.id'
    }
);

sub as_string {
    my $self = shift;
    sprintf "[%d] %s\n%s\n", $self->id, $self->title, $self->url;
}

1;
