package App::Schema::User;
use strict;
use warnings;
use base qw/DBIx::Class/;
use DateTime;

__PACKAGE__->load_components(qw/PK::Auto Core/);
__PACKAGE__->table('user');
__PACKAGE__->add_columns(qw/id name/);
__PACKAGE__->set_primary_key('id');
__PACKAGE__->add_unique_constraint([qw/name/]);
__PACKAGE__->has_many(
    bookmarks => 'App::Schema::Bookmark', {
        'foreign.user_id' => 'self.id'
    }
);

sub add_bookmark {
    my ($self, $entry, $comment) = @_;
    $self->add_to_bookmarks({
        entry_id   => $entry->id,
        comment    => $comment || '',
        created_on => DateTime->now,
    });
}

sub delete_bookmark {
    my ($self, $entry_id) = @_;
    $self->search_related('bookmarks', { entry_id => $entry_id })->delete;
}

sub already_has {
    my ($self, $entry) = @_;
    $self->search_related('bookmarks', { entry_id => $entry->id })->single ? 1 : 0;
}

1;
