#!/usr/local/bin/perl
use strict;
use warnings;
use lib qw(./blib);
use App::Schema;

my $schema = App::Schema->connect;
$schema->storage->debug(1);

my $rs = $schema->resultset('User');

# CREATE
my $new_user = $rs->create({ name => 'ally' });
$new_user->delete;

my $another_user = $rs->find_or_create({ name => 'naoya2006' });
my $yet_another = $rs->find_or_new({ name => 'naoya_hoge' });

# READ
my $users = $rs->search(undef, { order_by => 'id desc' });
$users = $rs->search({ id => {'>', '5'}}); # SQL::Abstract

while (my $user = $users->next) {
    print $user->name, "\n";
}

$users = $rs->search({ name => 'naoya' });
$users = $rs->search_like({ name => 'naoya%' });
$users = $rs->search_literal('name => ?', 'naoya');

# UPDATE
my $user = $rs->find({name => 'naoya'});
$user->name('naoya_ito');
$user->update;

# DELETE
$user->delete;
$rs->search_like({ name => 'naoya%' })->delete;

# POPULATE
$schema->populate(
    'User',
    [[qw/name/], ['naoya'], ['naoya2006']]
);

# LAZY
print $rs->search_like({ name => 'naoya%' })->search({ id => {'>', '5'} })->count;

